@@ -44,23 +44,21 @@ enum
 	COL_MEM,
 	COL_PIXBUF,
 	COL_POINTER,
+	COL_TOOLTIP,
 	NUM_COLUMNS
 };
 
 
-GtkWidget*	proctable_new (ProcData *data) G_GNUC_INTERNAL;
-void		proctable_update_table (ProcData *data) G_GNUC_INTERNAL;
-void		proctable_update_list (ProcData *data) G_GNUC_INTERNAL;
-void		insert_info_to_tree (ProcInfo *info, ProcData *procdata) G_GNUC_INTERNAL;
-void		remove_info_from_tree (ProcInfo *info, ProcData *procdata) G_GNUC_INTERNAL;
-ProcInfo *	proctable_find_process (guint pid, ProcData *procdata) G_GNUC_INTERNAL;
-void		proctable_update_all (ProcData *data) G_GNUC_INTERNAL;
-void		proctable_clear_tree (ProcData *data) G_GNUC_INTERNAL;
-void		proctable_free_table (ProcData *data) G_GNUC_INTERNAL;
+GtkWidget*	proctable_new (ProcData *data);
+void		proctable_update_table (ProcData *data);
+void		proctable_update_list (ProcData *data);
+void		proctable_update_all (ProcData *data);
+void		proctable_clear_tree (ProcData *data);
+void		proctable_free_table (ProcData *data);
 
-GSList*		proctable_get_columns_order(GtkTreeView *treeview) G_GNUC_INTERNAL;
-void		proctable_set_columns_order(GtkTreeView *treeview, GSList *order) G_GNUC_INTERNAL;
+GSList*		proctable_get_columns_order(GtkTreeView *treeview);
+void		proctable_set_columns_order(GtkTreeView *treeview, GSList *order);
 
-char*		make_loadavg_string(void) G_GNUC_INTERNAL;
+char*		make_loadavg_string(void);
 
 #endif /* _PROCMAN_PROCTABLE_H_ */
